@@ -14,40 +14,20 @@
 
 # Adding the current directory to the path, so that sphinx finds the
 # extensions.
-import sys, os
-sys.path.append(os.path.abspath('sphinxext'))
-
+import os
+try:
+    # When translating the docs to another language, this variable is set 
+    # elsewhere, so if it is not set, set it to a suitable default.
+    basedir
+except NameError:
+    basedir = os.path.dirname(os.path.abspath(__file__))
 
 # General configuration
 # ---------------------
 
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc', 'sphinxext.traitsdoc']
-
-## An autodocumentation processor, to insert title of functions before
-## the auto-documented functions:
-#def add_title(app, what, name, obj, options, signature, return_annotation):
-#    """ Add a section title with the name of the function before the
-#        docstring.
-#    """
-#    if what is not 'function':
-#        return
-#    short_name = name.split('.')[-1]
-#    extra_lines = """
-#
-#%s
-#...........................................
-#
-#    """ % short_name
-#    return extra_lines + signature, return_annotation
-#
-#
-#def setup(app):
-#    """ Register our docstring processor.
-#    """
-#    app.connect('autodoc-process-signature', add_title)
-
+extensions = ['sphinx.ext.autodoc', 'traits.util.trait_documenter']
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
@@ -60,12 +40,12 @@ master_doc = 'index'
 
 # General substitutions.
 project = 'mayavi'
-copyright = u'2008-2016, Enthought Inc.'
+copyright = u'2008-2018, Enthought Inc.'
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
 d = {}
-fname = os.path.join('..', '..', '..', 'mayavi', '__init__.py')
+fname = os.path.join(basedir, '..', '..', '..', 'mayavi', '__init__.py')
 exec(compile(open(fname).read(), fname, 'exec'), d)
 version = release = d['__version__']
 
@@ -166,7 +146,10 @@ latex_logo = 'm2_about.jpg'
 # If false, no module index is generated.
 #latex_use_modindex = True
 
+# To specify names to enable gettext extracting and translation applying for i18n additionally. You can specify below names:
+gettext_additional_targets = ['raw'] 
+
 ################################################################################
 # A hack:
 import shutil
-shutil.copyfile('../../CHANGES.txt', './auto/changes.rst')
+shutil.copyfile(os.path.join(basedir, '../../CHANGES.txt'), os.path.join(basedir, './auto/changes.rst'))
