@@ -2,29 +2,28 @@
 highest level.
 
 """
-# Author: Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2005-2008, Enthought, Inc.
+# Author: Prabhu Ramachandran <prabhu@aero.iitb.ac.in>
+# Copyright (c) 2005-2022, Enthought, Inc.
 # License: BSD Style.
 
 # Standard library imports.
 # VTK is used to just shut off the warnings temporarily.
 try:
     import vtk
-except ImportError, m:
-    m.args = ('%s\n%s\nDo you have vtk and its Python bindings installed properly?' %
-                    (m.args[0], '_'*80),)
+except ImportError as m:
+    m.args = ('%s\n%s\nDo you have vtk and its Python bindings '
+              'installed properly?' % (m.args[0], '_'*80),)
     raise
 
 # Enthought library imports.
 from traits.api import (HasStrictTraits, List, Str,
-        Property, Instance, Event, HasTraits, Callable, Dict,
-        Bool, on_trait_change, WeakRef)
+                        Property, Instance, Event, HasTraits, Callable, Dict,
+                        Bool, on_trait_change, WeakRef)
 from traitsui.api import View, Item
 from apptools.persistence import state_pickler
 from apptools.scripting.api import Recorder, recordable
 
 # Local imports.
-from tvtk.common import is_old_pipeline
 from mayavi.core.base import Base
 from mayavi.core.scene import Scene
 from mayavi.core.common import error, process_ui_events
@@ -44,13 +43,17 @@ def _id_generator():
     while True:
         yield(n)
         n += 1
+
+
 scene_id_generator = _id_generator()
 
+
 def get_args(function):
     """ Simple inspect-like function to inspect the arguments a function
         takes.
     """
-    return function.func_code.co_varnames[:function.func_code.co_argcount]
+    return function.__code__.co_varnames[:function.__code__.co_argcount]
+
 
 ######################################################################
 # `Engine` class
@@ -116,13 +119,14 @@ class Engine(HasStrictTraits):
     _viewer_ref = Dict
 
     # View related traits.
-    current_selection_view = View(Item(name='_current_selection',
-                                       enabled_when='_current_selection is not None',
-                                       style='custom', springy=True,
-                                       show_label=False,),
-                                  resizable=True,
-                                  scrollable=True
-                                  )
+    current_selection_view = View(
+        Item(name='_current_selection',
+             enabled_when='_current_selection is not None',
+             style='custom', springy=True,
+             show_label=False,),
+        resizable=True,
+        scrollable=True
+    )
 
     ######################################################################
     # `object` interface
@@ -135,8 +139,9 @@ class Engine(HasStrictTraits):
 
         # To remove ref cycle with root preferences helper, the trait change
         # handler is an instance method
-        preference_manager.root.on_trait_change(self._show_helper_nodes_changed,
-                                                'show_helper_nodes')
+        preference_manager.root.on_trait_change(
+            self._show_helper_nodes_changed, 'show_helper_nodes'
+        )
 
     def __get_pure_state__(self):
         d = self.__dict__.copy()
@@ -189,7 +194,6 @@ class Engine(HasStrictTraits):
     def add_source(self, src, scene=None):
         """Adds a source to the pipeline. Uses the current scene unless a
         scene is given in the scene keyword argument."""
-        passed_scene = scene
         if scene is not None:
             tvtk_scene = scene.scene
             for sc in self.scenes:
@@ -215,7 +219,6 @@ class Engine(HasStrictTraits):
         to the selected object, or to an object passed as the
         kwarg `obj`.
         """
-        passed_obj = obj
         if obj is None:
             obj = self.current_object
         if not isinstance(obj, Base):
@@ -253,19 +256,16 @@ class Engine(HasStrictTraits):
         # Save the state of VTK's global warning display.
         o = vtk.vtkObject
         w = o.GetGlobalWarningDisplay()
-        o.SetGlobalWarningDisplay(0) # Turn it off.
+        o.SetGlobalWarningDisplay(0)  # Turn it off.
         try:
-            #FIXME: This is for streamline seed point widget position which 
-            #does not get serialized correctly
-            if is_old_pipeline():
-                state_pickler.dump(self, file_or_fname)
-            else:
-                state = state_pickler.get_state(self)
-                st = state.scenes[0].children[0].children[0].children[4]
-                l_pos = st.seed.widget.position
-                st.seed.widget.position = [pos.item() for pos in l_pos]
-                saved_state = state_pickler.dumps(state)
-                file_or_fname.write(saved_state)
+            # FIXME: This is for streamline seed point widget position which
+            # does not get serialized correctly
+            state = state_pickler.get_state(self)
+            st = state.scenes[0].children[0].children[0].children[4]
+            l_pos = st.seed.widget.position
+            st.seed.widget.position = [pos.item() for pos in l_pos]
+            saved_state = state_pickler.dumps(state)
+            file_or_fname.write(saved_state)
         except (IndexError, AttributeError):
             state_pickler.dump(self, file_or_fname)
         finally:
@@ -308,7 +308,7 @@ class Engine(HasStrictTraits):
         passed_scene = scene
         reader = registry.get_file_reader(filename)
         if reader is None:
-            msg = 'No suitable reader found for the file %s'%filename
+            msg = 'No suitable reader found for the file %s' % filename
             error(msg)
         else:
             src = None
@@ -371,7 +371,7 @@ class Engine(HasStrictTraits):
             if hasattr(scene, 'name'):
                 name = scene.name
             else:
-                name = 'Mayavi Scene %d'%scene_id_generator.next()
+                name = 'Mayavi Scene %d' % next(scene_id_generator)
 
         s = Scene(scene=scene, name=name, parent=self)
         s.start()
@@ -445,7 +445,7 @@ class Engine(HasStrictTraits):
         if viewer is None:
             factory_kwargs = {}
             factory_kwargs_names = get_args(self.scene_factory)
-            for arg, value in kwargs.iteritems():
+            for arg, value in kwargs.items():
                 if arg in factory_kwargs_names:
                     factory_kwargs[arg] = value
 
@@ -468,7 +468,6 @@ class Engine(HasStrictTraits):
                 self.current_scene.sync_trait('name', viewer, 'title')
         return viewer
 
-
     @recordable
     def close_scene(self, scene):
         """Given a scene created from new_scene, this method closes it
@@ -579,9 +578,9 @@ class Engine(HasStrictTraits):
         """
         self._viewer_ref.clear()
         self.scenes = []
-        preference_manager.root.on_trait_change(self._show_helper_nodes_changed,
-                                                'show_helper_nodes',
-                                                remove=True)
+        preference_manager.root.on_trait_change(
+            self._show_helper_nodes_changed, 'show_helper_nodes', remove=True
+        )
         registry.unregister_engine(self)
 
     def _show_helper_nodes_changed(self):
@@ -591,8 +590,8 @@ class Engine(HasStrictTraits):
     def _get_children_ui_list(self):
         """ Trait getter for children_ui_list Property.
         """
-        if preference_manager.root.show_helper_nodes \
-                    and len(self.scenes) == 0:
+        if (preference_manager.root.show_helper_nodes and
+           len(self.scenes) == 0):
             return [SceneAdderNode(object=self)]
         else:
             return self.scenes
@@ -620,4 +619,3 @@ class Engine(HasStrictTraits):
             old.record('# ------------------------------------------- ')
             old.record('from mayavi.tools.show import show')
             old.record('show()')
-
