@@ -1,6 +1,6 @@
 # Author: Suyog Dutt Jain <suyog.jain@aero.iitb.ac.in>
 #         Prabhu Ramachandran <prabhu_r@users.sf.net>
-# Copyright (c) 2008-2015,  Enthought, Inc.
+# Copyright (c) 2008-2020,  Enthought, Inc.
 # License: BSD Style.
 
 # Standard library imports.
@@ -56,7 +56,7 @@ class TestGridPlane(unittest.TestCase):
         gp3.grid_plane.position = 6
 
         for gp in (gp1, gp2, gp3):
-            gp.actor.property.set(ambient=1.0)
+            gp.actor.property.trait_set(ambient=1.0)
 
         self.scene = e.current_scene
         return
