@@ -69,7 +69,7 @@ def figure(figure=None, bgcolor=None, fgcolor=None, engine=None,
             engine.new_scene(name=name, size=size)
             engine.current_scene.name = name
         else:
-            if type(figure) in (int, np.int0, np.int8,
+            if type(figure) in (int, np.intp, np.int8,
                                 np.int16, np.int32, np.int64):
                 name = int(figure)
                 __scene_number_list.update((name,))
@@ -165,7 +165,7 @@ def close(scene=None, all=False):
         if scene is None:
             scene = engine.current_scene
         else:
-            if type(scene) in (int, np.int0, np.int8,
+            if type(scene) in (int, np.intp, np.int8,
                                np.int16, np.int32, np.int64):
                 scene = int(scene)
                 name = 'Mayavi Scene %d' % scene
