@@ -47,6 +47,8 @@ if qt_api == 'pyqt':
     PyQtImpl = "PyQt4"
 elif qt_api == 'pyqt5':
     PyQtImpl = "PyQt5"
+elif qt_api == 'pyqt6':
+    PyQtImpl = "PyQt6"
 elif qt_api == 'pyside2':
     PyQtImpl = "PySide2"
 elif qt_api == 'pyside6':
@@ -67,56 +69,138 @@ try:
 except (ImportError, AttributeError):
     pass
 
-if PyQtImpl == "PyQt5":
+# Check the compatibility of PyQtImpl and QVTKRWIBase
+if QVTKRWIBase != "QWidget":
+    if PyQtImpl in ["PySide6", "PyQt6"] and QVTKRWIBase == "QOpenGLWidget":
+        pass  # compatible
+    elif PyQtImpl in ["PyQt5", "PySide2","PyQt4", "PySide"] and QVTKRWIBase == "QGLWidget":
+        pass  # compatible
+    else:
+        raise ImportError("Cannot load " + QVTKRWIBase + " from " + PyQtImpl)
+
+if PyQtImpl == "PySide6":
+    if QVTKRWIBase == "QOpenGLWidget":
+        from PySide6.QtOpenGLWidgets import QOpenGLWidget
+    from PySide6.QtWidgets import QWidget
+    from PySide6.QtWidgets import QSizePolicy
+    from PySide6.QtWidgets import QApplication
+    from PySide6.QtWidgets import QMainWindow
+    from PySide6.QtGui import QCursor
+    from PySide6.QtCore import Qt
+    from PySide6.QtCore import QTimer
+    from PySide6.QtCore import QObject
+    from PySide6.QtCore import QSize
+    from PySide6.QtCore import QEvent
+elif PyQtImpl == "PyQt6":
+    if QVTKRWIBase == "QOpenGLWidget":
+        from PyQt6.QtOpenGLWidgets import QOpenGLWidget
+    from PyQt6.QtWidgets import QWidget
+    from PyQt6.QtWidgets import QSizePolicy
+    from PyQt6.QtWidgets import QApplication
+    from PyQt6.QtWidgets import QMainWindow
+    from PyQt6.QtGui import QCursor
+    from PyQt6.QtCore import Qt
+    from PyQt6.QtCore import QTimer
+    from PyQt6.QtCore import QObject
+    from PyQt6.QtCore import QSize
+    from PyQt6.QtCore import QEvent
+elif PyQtImpl == "PyQt5":
     if QVTKRWIBase == "QGLWidget":
-        try:
-            from PyQt5.QtWidgets import QOpenGLWidget as QGLWidget
-        except:
-            from PyQt5.QtOpenGL import QGLWidget
-    from PyQt5.QtWidgets import QWidget, QSizePolicy, QApplication
-    from PyQt5.QtGui import QWheelEvent
-    from PyQt5.QtCore import Qt, QTimer, QObject, QSize, QEvent
+        from PyQt5.QtOpenGL import QGLWidget
+    from PyQt5.QtWidgets import QWidget
+    from PyQt5.QtWidgets import QSizePolicy
+    from PyQt5.QtWidgets import QApplication
+    from PyQt5.QtWidgets import QMainWindow
+    from PyQt5.QtGui import QCursor
+    from PyQt5.QtCore import Qt
+    from PyQt5.QtCore import QTimer
+    from PyQt5.QtCore import QObject
+    from PyQt5.QtCore import QSize
+    from PyQt5.QtCore import QEvent
+elif PyQtImpl == "PySide2":
+    if QVTKRWIBase == "QGLWidget":
+        from PySide2.QtOpenGL import QGLWidget
+    from PySide2.QtWidgets import QWidget
+    from PySide2.QtWidgets import QSizePolicy
+    from PySide2.QtWidgets import QApplication
+    from PySide2.QtWidgets import QMainWindow
+    from PySide2.QtGui import QCursor
+    from PySide2.QtCore import Qt
+    from PySide2.QtCore import QTimer
+    from PySide2.QtCore import QObject
+    from PySide2.QtCore import QSize
+    from PySide2.QtCore import QEvent
 elif PyQtImpl == "PyQt4":
     if QVTKRWIBase == "QGLWidget":
         from PyQt4.QtOpenGL import QGLWidget
-    from PyQt4.QtGui import QWidget, QSizePolicy, QApplication, QWheelEvent
-    from PyQt4.QtCore import Qt, QTimer, QObject, QSize, QEvent
+    from PyQt4.QtGui import QWidget
+    from PyQt4.QtGui import QSizePolicy
+    from PyQt4.QtGui import QApplication
+    from PyQt4.QtGui import QMainWindow
+    from PyQt4.QtCore import Qt
+    from PyQt4.QtCore import QTimer
+    from PyQt4.QtCore import QObject
+    from PyQt4.QtCore import QSize
+    from PyQt4.QtCore import QEvent
 elif PyQtImpl == "PySide":
     if QVTKRWIBase == "QGLWidget":
         from PySide.QtOpenGL import QGLWidget
-    from PySide.QtGui import QWidget, QSizePolicy, QApplication, QWheelEvent
-    from PySide.QtCore import Qt, QTimer, QObject, QSize, QEvent
-elif PyQtImpl == "PySide2":
-    if QVTKRWIBase == "QGLWidget":
-        try:
-            from PySide2.QtWidgets import QOpenGLWidget as QGLWidget
-        except:
-            from PySide2.QtOpenGL import QGLWidget
-    from PySide2.QtWidgets import QWidget, QSizePolicy, QApplication
-    from PySide2.QtGui import QWheelEvent
-    from PySide2.QtCore import Qt, QTimer, QObject, QSize, QEvent
-elif PyQtImpl == "PySide6":
-    if QVTKRWIBase == "QGLWidget":
-        try:
-            from PySide6.QtWidgets import QOpenGLWidget as QGLWidget
-        except:
-            from PySide6.QtOpenGL import QGLWidget
-    from PySide6.QtWidgets import QWidget, QSizePolicy, QApplication
-    from PySide6.QtGui import QWheelEvent
-    from PySide6.QtCore import Qt, QTimer, QObject, QSize, QEvent
+    from PySide.QtGui import QWidget
+    from PySide.QtGui import QSizePolicy
+    from PySide.QtGui import QApplication
+    from PySide.QtGui import QMainWindow
+    from PySide.QtCore import Qt
+    from PySide.QtCore import QTimer
+    from PySide.QtCore import QObject
+    from PySide.QtCore import QSize
+    from PySide.QtCore import QEvent
 else:
     raise ImportError("Unknown PyQt implementation " + repr(PyQtImpl))
 
-
 # Define types for base class, based on string
 if QVTKRWIBase == "QWidget":
     QVTKRWIBaseClass = QWidget
 elif QVTKRWIBase == "QGLWidget":
     QVTKRWIBaseClass = QGLWidget
+elif QVTKRWIBase == "QOpenGLWidget":
+    QVTKRWIBaseClass = QOpenGLWidget
 else:
-    raise ImportError(
-        "Unknown base class for QVTKRenderWindowInteractor " + QVTKRWIBase
-    )
+    raise ImportError("Unknown base class for QVTKRenderWindowInteractor " + QVTKRWIBase)
+
+if PyQtImpl == 'PyQt6':
+    CursorShape = Qt.CursorShape
+    WidgetAttribute = Qt.WidgetAttribute
+    FocusPolicy = Qt.FocusPolicy
+    ConnectionType = Qt.ConnectionType
+    Key = Qt.Key
+    SizePolicy = QSizePolicy.Policy
+    EventType = QEvent.Type
+    try:
+        MouseButton = Qt.MouseButton
+        WindowType = Qt.WindowType
+        KeyboardModifier = Qt.KeyboardModifier
+    except AttributeError:
+        # Fallback solution for PyQt6 versions < 6.1.0
+        MouseButton = Qt.MouseButtons
+        WindowType = Qt.WindowFlags
+        KeyboardModifier = Qt.KeyboardModifiers
+else:
+    CursorShape = MouseButton = WindowType = WidgetAttribute = \
+        KeyboardModifier = FocusPolicy = ConnectionType = Key = Qt
+    SizePolicy = QSizePolicy
+    EventType = QEvent
+
+if PyQtImpl in ('PyQt4', 'PySide'):
+    MiddleButton = MouseButton.MidButton
+else:
+    MiddleButton = MouseButton.MiddleButton
+
+
+def _get_event_pos(ev):
+    try:  # Qt6+
+        return ev.position().x(), ev.position().y()
+    except AttributeError:  # Qt5
+        return ev.x(), ev.y()
 
 
 class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
@@ -190,28 +274,28 @@ class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
 
     # Map between VTK and Qt cursors.
     _CURSOR_MAP = {
-        0:  Qt.ArrowCursor,          # VTK_CURSOR_DEFAULT
-        1:  Qt.ArrowCursor,          # VTK_CURSOR_ARROW
-        2:  Qt.SizeBDiagCursor,      # VTK_CURSOR_SIZENE
-        3:  Qt.SizeFDiagCursor,      # VTK_CURSOR_SIZENWSE
-        4:  Qt.SizeBDiagCursor,      # VTK_CURSOR_SIZESW
-        5:  Qt.SizeFDiagCursor,      # VTK_CURSOR_SIZESE
-        6:  Qt.SizeVerCursor,        # VTK_CURSOR_SIZENS
-        7:  Qt.SizeHorCursor,        # VTK_CURSOR_SIZEWE
-        8:  Qt.SizeAllCursor,        # VTK_CURSOR_SIZEALL
-        9:  Qt.PointingHandCursor,   # VTK_CURSOR_HAND
-        10: Qt.CrossCursor,          # VTK_CURSOR_CROSSHAIR
+        0:  CursorShape.ArrowCursor,          # VTK_CURSOR_DEFAULT
+        1:  CursorShape.ArrowCursor,          # VTK_CURSOR_ARROW
+        2:  CursorShape.SizeBDiagCursor,      # VTK_CURSOR_SIZENE
+        3:  CursorShape.SizeFDiagCursor,      # VTK_CURSOR_SIZENWSE
+        4:  CursorShape.SizeBDiagCursor,      # VTK_CURSOR_SIZESW
+        5:  CursorShape.SizeFDiagCursor,      # VTK_CURSOR_SIZESE
+        6:  CursorShape.SizeVerCursor,        # VTK_CURSOR_SIZENS
+        7:  CursorShape.SizeHorCursor,        # VTK_CURSOR_SIZEWE
+        8:  CursorShape.SizeAllCursor,        # VTK_CURSOR_SIZEALL
+        9:  CursorShape.PointingHandCursor,   # VTK_CURSOR_HAND
+        10: CursorShape.CrossCursor,          # VTK_CURSOR_CROSSHAIR
     }
 
     def __init__(self, parent=None, **kw):
         # the current button
-        self._ActiveButton = Qt.NoButton
+        self._ActiveButton = MouseButton.NoButton
 
         # private attributes
         self.__saveX = 0
         self.__saveY = 0
-        self.__saveModifiers = Qt.NoModifier
-        self.__saveButtons = Qt.NoButton
+        self.__saveModifiers = KeyboardModifier.NoModifier
+        self.__saveButtons = MouseButton.NoButton
         self.__wheelDelta = 0
 
         # do special handling of some keywords:
@@ -227,15 +311,17 @@ class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
         except KeyError:
             rw = None
 
-        # create qt-level widget
+        # create base qt-level widget
         if QVTKRWIBase == "QWidget":
             if "wflags" in kw:
                 wflags = kw['wflags']
             else:
-                wflags = Qt.WindowFlags()
-            QWidget.__init__(self, parent, wflags | Qt.MSWindowsOwnDC)
+                wflags = WindowType.Widget  # what Qt.WindowFlags() returns (0)
+            QWidget.__init__(self, parent, wflags | WindowType.MSWindowsOwnDC)
         elif QVTKRWIBase == "QGLWidget":
             QGLWidget.__init__(self, parent)
+        elif QVTKRWIBase == "QOpenGLWidget":
+            QOpenGLWidget.__init__(self, parent)
 
         if rw:  # user-supplied render window
             self._RenderWindow = rw
@@ -245,8 +331,6 @@ class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
         wid = self._get_win_id()
         self._RenderWindow.SetWindowInfo(wid)
 
-        self._should_set_parent_info = (sys.platform == 'win32')
-
         if stereo:  # stereo mode
             self._RenderWindow.StereoCapableWindowOn()
             self._RenderWindow.SetStereoTypeToCrystalEyes()
@@ -258,17 +342,12 @@ class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
 
         self._Iren.SetRenderWindow(self._RenderWindow)
 
-        if hasattr(self, 'devicePixelRatio'):
-            self._pixel_ratio = self.devicePixelRatio()
-        else:
-            self._pixel_ratio = 1.0
-
         # do all the necessary qt setup
-        self.setAttribute(Qt.WA_OpaquePaintEvent)
-        self.setAttribute(Qt.WA_PaintOnScreen)
+        self.setAttribute(WidgetAttribute.WA_OpaquePaintEvent)
+        self.setAttribute(WidgetAttribute.WA_PaintOnScreen)
         self.setMouseTracking(True) # get all mouse events
-        self.setFocusPolicy(Qt.WheelFocus)
-        self.setSizePolicy(QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding))
+        self.setFocusPolicy(FocusPolicy.WheelFocus)
+        self.setSizePolicy(QSizePolicy(SizePolicy.Expanding, SizePolicy.Expanding))
 
         self._Timer = QTimer(self)
         self._Timer.timeout.connect(self.TimerEvent)
@@ -290,12 +369,11 @@ class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
         messenger.connect(self._RenderWindow, 'CursorChangedEvent',
                           self.CursorChangedEvent)
 
-        # Create a hidden child widget and connect its destroyed signal to its
-        # parent ``Finalize`` slot. The hidden children will be destroyed
-        # before its parent thus allowing cleanup of VTK elements.
-        self._hidden = QWidget(self)
-        self._hidden.hide()
-        self._hidden.destroyed.connect(self.Finalize)
+        # If we've a parent, it does not close the child when closed.
+        # Connect the parent's destroyed signal to this widget's close
+        # slot for proper cleanup of VTK objects.
+        if self.parent():
+            self.parent().destroyed.connect(self.close, ConnectionType.DirectConnection)
 
     def __getattr__(self, attr):
         """Makes the object behave like a vtkGenericRenderWindowInteractor"""
@@ -311,17 +389,7 @@ class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
     def _get_win_id(self):
         WId = self.winId()
 
-        # Python2
-        if type(WId).__name__ == 'PyCObject':
-            from ctypes import pythonapi, c_void_p, py_object
-
-            pythonapi.PyCObject_AsVoidPtr.restype  = c_void_p
-            pythonapi.PyCObject_AsVoidPtr.argtypes = [py_object]
-
-            WId = pythonapi.PyCObject_AsVoidPtr(WId)
-
-        # Python3
-        elif type(WId).__name__ == 'PyCapsule':
+        if type(WId).__name__ == 'PyCapsule':
             from ctypes import pythonapi, c_void_p, py_object, c_char_p
 
             pythonapi.PyCapsule_GetName.restype = c_char_p
@@ -360,12 +428,12 @@ class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
 
     def HideCursor(self):
         """Hides the cursor."""
-        self.setCursor(Qt.BlankCursor)
+        self.setCursor(CursorShape.BlankCursor)
 
     def ShowCursor(self):
         """Shows the cursor."""
         vtk_cursor = self._Iren.GetRenderWindow().GetCurrentCursor()
-        qt_cursor = self._CURSOR_MAP.get(vtk_cursor, Qt.ArrowCursor)
+        qt_cursor = self._CURSOR_MAP.get(vtk_cursor, CursorShape.ArrowCursor)
         self.setCursor(qt_cursor)
 
     def closeEvent(self, evt):
@@ -378,26 +446,16 @@ class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
         return None
 
     def paintEvent(self, ev):
+        # This is intentionally different from the upstream version. 
+        # When we call self._Iren.Render() this ends up initialing 
+        # the window too soon when the LightManager is created. 
         self._RenderWindow.Render()
 
     def resizeEvent(self, ev):
-        if self._should_set_parent_info:
-            # Set the window info and parent info on every resize.
-            # vtkWin32OpenGLRenderWindow will render using incorrect offsets if
-            # the parent info is not given to it because it assumes that it
-            # needs to make room for the title bar.
-            winid = self._get_win_id()
-            self._RenderWindow.SetWindowInfo(winid)
-            parent = self.parent()
-            if parent is not None:
-                self._RenderWindow.SetParentInfo(winid)
-            else:
-                self._RenderWindow.SetParentInfo('')
-
-        pxr = self._pixel_ratio
-        w = int(self.width()*pxr)
-        h = int(self.height()*pxr)
-
+        scale = self._getPixelRatio()
+        w = int(round(scale*self.width()))
+        h = int(round(scale*self.height()))
+        self._RenderWindow.SetDPI(int(round(72*scale)))
         vtk.vtkRenderWindow.SetSize(self._RenderWindow, w, h)
         self._Iren.SetSize(w, h)
         self._Iren.ConfigureEvent()
@@ -407,72 +465,94 @@ class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
         ctrl = shift = False
 
         if hasattr(ev, 'modifiers'):
-            if ev.modifiers() & Qt.ShiftModifier:
+            if ev.modifiers() & KeyboardModifier.ShiftModifier:
                 shift = True
-            if ev.modifiers() & Qt.ControlModifier:
+            if ev.modifiers() & KeyboardModifier.ControlModifier:
                 ctrl = True
         else:
-            if self.__saveModifiers & Qt.ShiftModifier:
+            if self.__saveModifiers & KeyboardModifier.ShiftModifier:
                 shift = True
-            if self.__saveModifiers & Qt.ControlModifier:
+            if self.__saveModifiers & KeyboardModifier.ControlModifier:
                 ctrl = True
 
         return ctrl, shift
 
+    @staticmethod
+    def _getPixelRatio():
+        if PyQtImpl in ["PyQt5", "PySide2", "PySide6", "PyQt6"]:
+            # Source: https://stackoverflow.com/a/40053864/3388962
+            pos = QCursor.pos()
+            for screen in QApplication.screens():
+                rect = screen.geometry()
+                if rect.contains(pos):
+                    return screen.devicePixelRatio()
+            # Should never happen, but try to find a good fallback.
+            return QApplication.instance().devicePixelRatio()
+        else:
+            # Qt4 seems not to provide any cross-platform means to get the
+            # pixel ratio.
+            return 1.
+
+    def _setEventInformation(self, x, y, ctrl, shift,
+                             key, repeat=0, keysum=None):
+        scale = self._getPixelRatio()
+        self._Iren.SetEventInformation(int(round(x*scale)),
+                                       int(round((self.height()-y-1)*scale)),
+                                       ctrl, shift, key, repeat, keysum)
+
     def enterEvent(self, ev):
         ctrl, shift = self._GetCtrlShift(ev)
-        self._Iren.SetEventInformationFlipY(self.__saveX, self.__saveY,
-                                            ctrl, shift, chr(0), 0, None)
+        self._setEventInformation(self.__saveX, self.__saveY,
+                                  ctrl, shift, chr(0), 0, None)
         self._Iren.EnterEvent()
 
     def leaveEvent(self, ev):
         ctrl, shift = self._GetCtrlShift(ev)
-        self._Iren.SetEventInformationFlipY(self.__saveX, self.__saveY,
-                                            ctrl, shift, chr(0), 0, None)
+        self._setEventInformation(self.__saveX, self.__saveY,
+                                  ctrl, shift, chr(0), 0, None)
         self._Iren.LeaveEvent()
 
     def mousePressEvent(self, ev):
         ctrl, shift = self._GetCtrlShift(ev)
         repeat = 0
-        if ev.type() == QEvent.MouseButtonDblClick:
+        if ev.type() == EventType.MouseButtonDblClick:
             repeat = 1
-
-        pxr = self._pixel_ratio
-        self._Iren.SetEventInformationFlipY(int(ev.x()*pxr), int(ev.y()*pxr),
-                                            ctrl, shift, chr(0), repeat, None)
+        x, y = _get_event_pos(ev)
+        self._setEventInformation(x, y,
+                                  ctrl, shift, chr(0), repeat, None)
 
         self._ActiveButton = ev.button()
 
-        if self._ActiveButton == Qt.LeftButton:
+        if self._ActiveButton == MouseButton.LeftButton:
             self._Iren.LeftButtonPressEvent()
-        elif self._ActiveButton == Qt.RightButton:
+        elif self._ActiveButton == MouseButton.RightButton:
             self._Iren.RightButtonPressEvent()
-        elif self._ActiveButton == Qt.MidButton:
+        elif self._ActiveButton == MiddleButton:
             self._Iren.MiddleButtonPressEvent()
 
     def mouseReleaseEvent(self, ev):
         ctrl, shift = self._GetCtrlShift(ev)
-        pxr = self._pixel_ratio
-        self._Iren.SetEventInformationFlipY(int(ev.x()*pxr), int(ev.y()*pxr),
-                                            ctrl, shift, chr(0), 0, None)
+        x, y = _get_event_pos(ev)
+        self._setEventInformation(x, y,
+                                  ctrl, shift, chr(0), 0, None)
 
-        if self._ActiveButton == Qt.LeftButton:
+        if self._ActiveButton == MouseButton.LeftButton:
             self._Iren.LeftButtonReleaseEvent()
-        elif self._ActiveButton == Qt.RightButton:
+        elif self._ActiveButton == MouseButton.RightButton:
             self._Iren.RightButtonReleaseEvent()
-        elif self._ActiveButton == Qt.MidButton:
+        elif self._ActiveButton == MiddleButton:
             self._Iren.MiddleButtonReleaseEvent()
 
     def mouseMoveEvent(self, ev):
         self.__saveModifiers = ev.modifiers()
         self.__saveButtons = ev.buttons()
-        pxr = self._pixel_ratio
-        self.__saveX = int(ev.x()*pxr)
-        self.__saveY = int(ev.y()*pxr)
+        x, y = _get_event_pos(ev)
+        self.__saveX = x
+        self.__saveY = y
 
         ctrl, shift = self._GetCtrlShift(ev)
-        self._Iren.SetEventInformationFlipY(int(ev.x()*pxr), int(ev.y()*pxr),
-                                            ctrl, shift, chr(0), 0, None)
+        self._setEventInformation(x, y,
+                                  ctrl, shift, chr(0), 0, None)
         self._Iren.MouseMoveEvent()
 
     def keyPressEvent(self, ev):
@@ -502,8 +582,8 @@ class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
         if ev.isAutoRepeat():
             key = key[0]
 
-        self._Iren.SetEventInformationFlipY(self.__saveX, self.__saveY,
-                                            ctrl, shift, key, 0, key_sym)
+        self._setEventInformation(self.__saveX, self.__saveY,
+                                  ctrl, shift, key, 0, key_sym)
         self._Iren.KeyPressEvent()
         self._Iren.CharEvent()
 
@@ -519,8 +599,8 @@ class QVTKRenderWindowInteractor(QVTKRWIBaseClass):
         else:
             key = chr(0)
 
-        self._Iren.SetEventInformationFlipY(self.__saveX, self.__saveY,
-                                            ctrl, shift, key, 0, None)
+        self._setEventInformation(self.__saveX, self.__saveY,
+                                  ctrl, shift, key, 0, key_sym)
         self._Iren.KeyReleaseEvent()
 
     def wheelEvent(self, ev):
@@ -605,98 +685,98 @@ def QVTKRenderWidgetConeExample():
 
 
 _keysyms = {
-    Qt.Key_Backspace: 'BackSpace',
-    Qt.Key_Tab: 'Tab',
-    Qt.Key_Backtab: 'Tab',
-    # Qt.Key_Clear : 'Clear',
-    Qt.Key_Return: 'Return',
-    Qt.Key_Enter: 'Return',
-    Qt.Key_Shift: 'Shift_L',
-    Qt.Key_Control: 'Control_L',
-    Qt.Key_Alt: 'Alt_L',
-    Qt.Key_Pause: 'Pause',
-    Qt.Key_CapsLock: 'Caps_Lock',
-    Qt.Key_Escape: 'Escape',
-    Qt.Key_Space: 'space',
-    # Qt.Key_Prior : 'Prior',
-    # Qt.Key_Next : 'Next',
-    Qt.Key_End: 'End',
-    Qt.Key_Home: 'Home',
-    Qt.Key_Left: 'Left',
-    Qt.Key_Up: 'Up',
-    Qt.Key_Right: 'Right',
-    Qt.Key_Down: 'Down',
-    Qt.Key_SysReq: 'Snapshot',
-    Qt.Key_Insert: 'Insert',
-    Qt.Key_Delete: 'Delete',
-    Qt.Key_Help: 'Help',
-    Qt.Key_0: '0',
-    Qt.Key_1: '1',
-    Qt.Key_2: '2',
-    Qt.Key_3: '3',
-    Qt.Key_4: '4',
-    Qt.Key_5: '5',
-    Qt.Key_6: '6',
-    Qt.Key_7: '7',
-    Qt.Key_8: '8',
-    Qt.Key_9: '9',
-    Qt.Key_A: 'a',
-    Qt.Key_B: 'b',
-    Qt.Key_C: 'c',
-    Qt.Key_D: 'd',
-    Qt.Key_E: 'e',
-    Qt.Key_F: 'f',
-    Qt.Key_G: 'g',
-    Qt.Key_H: 'h',
-    Qt.Key_I: 'i',
-    Qt.Key_J: 'j',
-    Qt.Key_K: 'k',
-    Qt.Key_L: 'l',
-    Qt.Key_M: 'm',
-    Qt.Key_N: 'n',
-    Qt.Key_O: 'o',
-    Qt.Key_P: 'p',
-    Qt.Key_Q: 'q',
-    Qt.Key_R: 'r',
-    Qt.Key_S: 's',
-    Qt.Key_T: 't',
-    Qt.Key_U: 'u',
-    Qt.Key_V: 'v',
-    Qt.Key_W: 'w',
-    Qt.Key_X: 'x',
-    Qt.Key_Y: 'y',
-    Qt.Key_Z: 'z',
-    Qt.Key_Asterisk: 'asterisk',
-    Qt.Key_Plus: 'plus',
-    Qt.Key_Minus: 'minus',
-    Qt.Key_Period: 'period',
-    Qt.Key_Slash: 'slash',
-    Qt.Key_F1: 'F1',
-    Qt.Key_F2: 'F2',
-    Qt.Key_F3: 'F3',
-    Qt.Key_F4: 'F4',
-    Qt.Key_F5: 'F5',
-    Qt.Key_F6: 'F6',
-    Qt.Key_F7: 'F7',
-    Qt.Key_F8: 'F8',
-    Qt.Key_F9: 'F9',
-    Qt.Key_F10: 'F10',
-    Qt.Key_F11: 'F11',
-    Qt.Key_F12: 'F12',
-    Qt.Key_F13: 'F13',
-    Qt.Key_F14: 'F14',
-    Qt.Key_F15: 'F15',
-    Qt.Key_F16: 'F16',
-    Qt.Key_F17: 'F17',
-    Qt.Key_F18: 'F18',
-    Qt.Key_F19: 'F19',
-    Qt.Key_F20: 'F20',
-    Qt.Key_F21: 'F21',
-    Qt.Key_F22: 'F22',
-    Qt.Key_F23: 'F23',
-    Qt.Key_F24: 'F24',
-    Qt.Key_NumLock: 'Num_Lock',
-    Qt.Key_ScrollLock: 'Scroll_Lock',
+    Key.Key_Backspace: 'BackSpace',
+    Key.Key_Tab: 'Tab',
+    Key.Key_Backtab: 'Tab',
+    # Key.Key_Clear : 'Clear',
+    Key.Key_Return: 'Return',
+    Key.Key_Enter: 'Return',
+    Key.Key_Shift: 'Shift_L',
+    Key.Key_Control: 'Control_L',
+    Key.Key_Alt: 'Alt_L',
+    Key.Key_Pause: 'Pause',
+    Key.Key_CapsLock: 'Caps_Lock',
+    Key.Key_Escape: 'Escape',
+    Key.Key_Space: 'space',
+    # Key.Key_Prior : 'Prior',
+    # Key.Key_Next : 'Next',
+    Key.Key_End: 'End',
+    Key.Key_Home: 'Home',
+    Key.Key_Left: 'Left',
+    Key.Key_Up: 'Up',
+    Key.Key_Right: 'Right',
+    Key.Key_Down: 'Down',
+    Key.Key_SysReq: 'Snapshot',
+    Key.Key_Insert: 'Insert',
+    Key.Key_Delete: 'Delete',
+    Key.Key_Help: 'Help',
+    Key.Key_0: '0',
+    Key.Key_1: '1',
+    Key.Key_2: '2',
+    Key.Key_3: '3',
+    Key.Key_4: '4',
+    Key.Key_5: '5',
+    Key.Key_6: '6',
+    Key.Key_7: '7',
+    Key.Key_8: '8',
+    Key.Key_9: '9',
+    Key.Key_A: 'a',
+    Key.Key_B: 'b',
+    Key.Key_C: 'c',
+    Key.Key_D: 'd',
+    Key.Key_E: 'e',
+    Key.Key_F: 'f',
+    Key.Key_G: 'g',
+    Key.Key_H: 'h',
+    Key.Key_I: 'i',
+    Key.Key_J: 'j',
+    Key.Key_K: 'k',
+    Key.Key_L: 'l',
+    Key.Key_M: 'm',
+    Key.Key_N: 'n',
+    Key.Key_O: 'o',
+    Key.Key_P: 'p',
+    Key.Key_Q: 'q',
+    Key.Key_R: 'r',
+    Key.Key_S: 's',
+    Key.Key_T: 't',
+    Key.Key_U: 'u',
+    Key.Key_V: 'v',
+    Key.Key_W: 'w',
+    Key.Key_X: 'x',
+    Key.Key_Y: 'y',
+    Key.Key_Z: 'z',
+    Key.Key_Asterisk: 'asterisk',
+    Key.Key_Plus: 'plus',
+    Key.Key_Minus: 'minus',
+    Key.Key_Period: 'period',
+    Key.Key_Slash: 'slash',
+    Key.Key_F1: 'F1',
+    Key.Key_F2: 'F2',
+    Key.Key_F3: 'F3',
+    Key.Key_F4: 'F4',
+    Key.Key_F5: 'F5',
+    Key.Key_F6: 'F6',
+    Key.Key_F7: 'F7',
+    Key.Key_F8: 'F8',
+    Key.Key_F9: 'F9',
+    Key.Key_F10: 'F10',
+    Key.Key_F11: 'F11',
+    Key.Key_F12: 'F12',
+    Key.Key_F13: 'F13',
+    Key.Key_F14: 'F14',
+    Key.Key_F15: 'F15',
+    Key.Key_F16: 'F16',
+    Key.Key_F17: 'F17',
+    Key.Key_F18: 'F18',
+    Key.Key_F19: 'F19',
+    Key.Key_F20: 'F20',
+    Key.Key_F21: 'F21',
+    Key.Key_F22: 'F22',
+    Key.Key_F23: 'F23',
+    Key.Key_F24: 'F24',
+    Key.Key_NumLock: 'Num_Lock',
+    Key.Key_ScrollLock: 'Scroll_Lock',
     }
 
 
@@ -714,4 +794,5 @@ def _qt_key_to_key_sym(key):
 
 
 if __name__ == "__main__":
+    print(PyQtImpl)
     QVTKRenderWidgetConeExample()
