@@ -702,6 +702,8 @@ class VTKMethodParser:
                              key == 'AttributesToInterpolate') or
                             (klass_name == 'vtkPlotBar' and
                              key == 'LookupTable') or
+                            (klass_name == 'vtkLagrangianParticleTracker' and
+                             key == 'IntegrationModel') or
                             False):  # just to simplify indentation/updates
                         default = None
                     else:
@@ -712,6 +714,20 @@ class VTKMethodParser:
                         except TypeError:
                             default = None
 
+                    # If we don't turn these into integers, they won't instantiate
+                    if is_version_9():
+                        if klass_name == "vtkAxisActor":
+                            if key in (
+                                "AxisOnOrigin", "Use2DMode", "UseTextActor3D",
+                            ):
+                                default = int(bool(default))
+                        elif klass_name in ("vtkCubeAxesActor", "vtkPolarAxesActor"):
+                            if key in (
+                                "EnableDistanceLOD", "EnableViewAngleLOD", "Use2DMode",
+                                "UseAxisOrigin", "UseOrientedBounds", "UseTextActor3D",
+                            ):
+                                default = int(bool(default))
+
                     if value:
                         low = getattr(obj, 'Get%sMinValue' % key)()
                         high = getattr(obj, 'Get%sMaxValue' % key)()
